<?php namespace Concrete\Package\EnlilStackLink\Block\EnlilStackLink;

use Concrete\Core\Page\Page;
use Concrete\Core\Block\BlockController;
use Concrete\Core\User\User;
use Concrete\Core\Permission\Checker as Permissions;


class Controller extends BlockController {
	
	protected $btInterfaceWidth = 500;
	protected $btInterfaceHeight = 350;
	protected $btTable = 'btEnlilStackLink';
	protected $btWrapperClass = 'ccm-ui';
	protected $btDefaultSet = 'enlil_stacks';
	
	protected $btCacheBlockRecord = false;
	protected $btCacheBlockOutput = false;
	protected $btCacheBlockOutputOnPost = false;
	protected $btCacheBlockOutputForRegisteredUsers = false;
	
	public function getBlockTypeName() {
		return t("Enlil Stack Link");
	}
	
	public function getBlockTypeDescription() {
		return t("Quick Links to Edit Stacks");
	}
	
	
	public function validate($args) {
		
		$e = $this->app->make('error');
		$page = Page::getCurrentPage();
		$stack = $this->isStack($page);
		
		// Restrict adding block to Areas & Global Areas on a Page
		if (!$stack) {
			
			$e->add(t('Stack Link Block MUST be placed in Stacks ONLY'));
		}
		
		// Restrict adding block to Global Areas in Dashboard
		if ($stack && $this->isStackGlobal($stack)) {
			
			$e->add(t('Stack Link Block MUST be placed in Stacks ONLY'));
		}
		
		return $e;
	}
	
	
	function save($args) {
		
		$args['slTarget'] = ($args['slTarget']) ? $args['slTarget'] : 0;
		
		//Auto Center block style buttons
		if (strpos($args['slBsClass'], 'block_') !== false) {
			
			$args['slBsAlign'] = 'center';
		}
		
		parent::save($args);
	}
	
	
	// Get Version 9 !!!
	public function isVersion9() {
		
		$v9 = false;
		$ccmVersionInstalled = \Concrete\Core\Support\Facade\Config::get('concrete.version_installed');
		if ($ccmVersionInstalled >= 9) {
			
			$v9 = true;
		}
		
		return $v9;
	}
	
	
	public function on_page_view() {
		
		// Hide copy to clipboard block menu option in edit mode
		$page = Page::getCurrentPage();
		$c = Page::getByID($this->getBlockCollectionID());
		
		if (is_object($page) && $page->isEditMode()) {
			
			$stack = $this->isStack($c);
			
			if ($stack || $this->isStackGlobal($stack)) { // or if the block happens to be in global area
				
				$style = '<style>#ccm-popover-menu-container > div[data-block-menu="block-menu-b' . $this->bID . '"] > div.popover-inner > ul.dropdown-menu > li > a[data-menu-action="block_scrapbook"] { display: none!important; }</style>';
				$this->addHeaderItem($style);
			}
		}
	}
	
	
	// Get Content //
	public function getContent() {
		
		$content = '';
		$c = Page::getByID($this->getBlockCollectionID());
		$stack = $this->isStack($c);
		
		if ($stack && !$this->isStackGlobal($stack)) {
			
			$cPermissions = new Permissions($c);
			if ($cPermissions->canEditPageContents()) { // Current User Can edit 'Contents'.  *Contents/Properties*
				
				$classParts = Array($this->getClass(), $this->getSize());
				$class = implode(' ', $classParts);
				
				$content = '<div class="' . $this->getAlign() . '"><a class="' . $class . '" href="' . $c->getCollectionLink() . '">' . t('Edit Stack: ') . $c->getCollectionName() . '</a></div>';
				if ($this->slTarget) {
					
					$content = '<div class="' . $this->getAlign() . '"><a class="' . $class . '" target="_blank" href="' . $c->getCollectionLink() . '">' . t('Edit Stack: ') . $c->getCollectionName() . '</a></div>';
				}
			}
		}
		
		return $content;
	}
	// Get Content END //

	
	public function getBlockCollectionID() {
	
		$blockCollectionID = Page::getCurrentPage()->getCollectionID();
		if ( is_object($this->block->getBlockCollectionObject()) ) {
			
			$blockCollectionID = $this->block->getBlockCollectionObject()->getCollectionID();
		}
		
		elseif ($this->block->isAlias()) {
			
			$blockCollectionID = $this->block->getBlockCollectionID();
		}
		
		return $blockCollectionID;
	}
	
	
	public function isStack($cObj = null) { // Return Stack Object (true) or false
		
		$isStack = false;
		if ($cObj instanceof \Concrete\Core\Page\Page) {
			
			//May return null if not a stack, rendering our next test useless.  Must test this at some point.  @mnakalay
			$cStack = \Concrete\Core\Page\Stack\Stack::getByID($cObj->getCollectionID());
			if ($cStack instanceof \Concrete\Core\Page\Stack\Stack) { //$stack->getPageTypeHandle() == STACKS_PAGE_TYPE;
				
				$isStack = $cStack;
			}
		}
		
		return $isStack;
	}
	
	
	public function isStackGlobal($sObj = null) {
		
		$isStackGlobal = false;
		if ($sObj instanceof \Concrete\Core\Page\Stack\Stack) {
			
			if ($sObj->getStackType() == \Concrete\Core\Page\Stack\Stack::ST_TYPE_GLOBAL_AREA) { // stackTypes 0 => Area | 20 => Global Area
				
				$isStackGlobal = true;
			}
		}
		
		return $isStackGlobal;
	}
	
	
	public function getEditModeWrap() {
		
		$c = Page::getByID($this->getBlockCollectionID());
		$stack = $this->isStack($c);
		$message = '';
		
		if (!$stack || $this->isStackGlobal($stack)) {
			
			// Block is on a Page or in a Global Area or in a clipboard block which we dont want and *shouldnt* happen
			$message = '<b><span class="text-danger">' . t('Block Not In Stack') . '</span></b><br>';
			$message = $message . '<b><small>' . t('No Output To Display') . '</small></b>';
		} // else { Block is in a Stack }
		
		$editModeWrapOpen = '<div class="ccm-edit-mode-disabled-item">';
		$editModeWrapOpen = $editModeWrapOpen . '<b>' . t('Enlil Stack Link') . '</b><br>';
		$editModeWrapOpen = $editModeWrapOpen . '<div class="clearfix" style="border-bottom: 1px solid #d0d0d0; margin-bottom: 4px;"></div>';
		$editModeWrapOpen = $editModeWrapOpen . $message;
		
		$editModeWrap = Array('open' => $editModeWrapOpen, 'close' => '</div>');
		
		return $editModeWrap;
	}
	
	
	public function getClass() {
	
		switch ($this->slBsClass) {
			
			case 'button_link':			$class = 'btn btn-link'; break;
			case 'button_default':
				if ($this->isVersion9()) {
					$class = 'btn btn-secondary'; break;
				} else {
					$class = 'btn btn-default'; break;
				}
			case 'button_primary':		$class = 'btn btn-primary'; break;
			case 'button_secondary':	$class = 'btn btn-secondary'; break;
			case 'button_success':		$class = 'btn btn-success'; break;
			case 'button_info':			$class = 'btn btn-info'; break;
			case 'button_warning':		$class = 'btn btn-warning'; break;
			case 'button_danger':		$class = 'btn btn-danger'; break;
			case 'button_light':		$class = 'btn btn-light'; break;
			case 'button_dark':			$class = 'btn btn-dark'; break;
			
			
			case 'button_outline-primary':		$class = 'btn btn-outline-primary'; break;
			case 'button_outline-secondary':	$class = 'btn btn-outline-secondary'; break;
			case 'button_outline-success':		$class = 'btn btn-outline-success'; break;
			case 'button_outline-info':			$class = 'btn btn-outline-info'; break;
			case 'button_outline-warning':		$class = 'btn btn-outline-warning'; break;
			case 'button_outline-danger':		$class = 'btn btn-outline-danger'; break;
			case 'button_outline-light':		$class = 'btn btn-outline-light'; break;
			case 'button_outline-dark':			$class = 'btn btn-outline-dark'; break;
			
			
			case 'button_alert-primary':	$class = 'btn btn-primary alert-primary'; break;
			case 'button_alert-secondary':	$class = 'btn btn-secondary alert-secondary'; break;
			case 'button_alert-success':	$class = 'btn btn-success alert-success'; break;
			case 'button_alert-info':		$class = 'btn btn-info alert-info'; break;
			case 'button_alert-warning':	$class = 'btn btn-warning alert-warning'; break;
			case 'button_alert-danger':		$class = 'btn btn-danger alert-danger'; break;
			case 'button_alert-light':		$class = 'btn btn-light alert-light'; break;
			case 'button_alert-dark':		$class = 'btn btn-dark alert-dark'; break;
				
				
			///////////////////////////////////////////////////////////////////////////////////////	
				
			
			case 'block_link':			$class = 'btn btn-link btn-block w-100'; break;
			case 'block_default':
				if ($this->isVersion9()) {
					$class = 'btn btn-secondary btn-block w-100'; break;
				} else {
					$class = 'btn btn-default btn-block w-100'; break;
				}
			case 'block_primary':		$class = 'btn btn-primary btn-block w-100'; break;
			case 'block_secondary':		$class = 'btn btn-secondary btn-block w-100'; break;
			case 'block_success':		$class = 'btn btn-success btn-block w-100'; break;
			case 'block_info':			$class = 'btn btn-info btn-block w-100'; break;
			case 'block_warning':		$class = 'btn btn-warning btn-block w-100'; break;
			case 'block_danger':		$class = 'btn btn-danger btn-block w-100'; break;
			case 'block_light':			$class = 'btn btn-light btn-block w-100'; break;
			case 'block_dark':			$class = 'btn btn-dark btn-block w-100'; break;
			
			
			case 'block_outline-primary':		$class = 'btn btn-outline-primary btn-block w-100'; break;
			case 'block_outline-secondary':		$class = 'btn btn-outline-secondary btn-block w-100'; break;
			case 'block_outline-success':		$class = 'btn btn-outline-success btn-block w-100'; break;
			case 'block_outline-info':			$class = 'btn btn-outline-info btn-block w-100'; break;
			case 'block_outline-warning':		$class = 'btn btn-outline-warning btn-block w-100'; break;
			case 'block_outline-danger':		$class = 'btn btn-outline-danger btn-block w-100'; break;
			case 'block_outline-light':			$class = 'btn btn-outline-light btn-block w-100'; break;
			case 'block_outline-dark':			$class = 'btn btn-outline-dark btn-block w-100'; break;
			
			
			case 'block_alert-primary':		$class = 'btn btn-primary btn-block w-100 alert-primary'; break;
			case 'block_alert-secondary':	$class = 'btn btn-secondary btn-block w-100 alert-secondary'; break;
			case 'block_alert-success':		$class = 'btn btn-success btn-block w-100 alert-success'; break;
			case 'block_alert-info':		$class = 'btn btn-info btn-block w-100 alert-info'; break;
			case 'block_alert-warning':		$class = 'btn btn-warning btn-block w-100 alert-warning'; break;
			case 'block_alert-danger':		$class = 'btn btn-danger btn-block w-100 alert-danger'; break;
			case 'block_alert-light':		$class = 'btn btn-light btn-block w-100 alert-light'; break;
			case 'block_alert-dark':		$class = 'btn btn-dark btn-block w-100 alert-dark'; break;
			
			
			default: $class = 'btn btn-link'; break;
		}
		
		return $class;
	}
	
	
	public function getSize() {
	
		switch ($this->slBsSize) {
			
			case 'xs':
				if ($this->isVersion9()) {
					$size = 'btn-sm'; break;
				} else {
					$size = 'btn-xs'; break;
				}
			case 'sm':
				$size = 'btn-sm'; break;
			case 'md':
				$size = 'btn-md'; break;
			case 'lg':
				$size = 'btn-lg'; break;
			
			
			default:
				$size = 'btn btn-sm'; break;
		}
		
		return $size;
	}
	
	
	public function getAlign() {
	
		switch ($this->slBsAlign) {
			
			case 'left':
				$align = 'text-left text-start'; break;
			case 'right':
				$align = 'text-right text-end'; break;
			case 'center':
				$align = 'text-center'; break;
			
			
			default:
				$align = 'text-left text-start'; break;
		}
		
		return $align;
	}
	
	
}
